Showcase
========

Here are some sites that have `django-allauth` up and running:

- `Drakdoo: Bitcoin trading app <http://www.drakdoo.com>`_
- `Flatmate Rooms: UK flatshare <https://www.flatmaterooms.co.uk>`_
- http://www.q-dance.com
- http://officecheese.com
- http://www.charityblossom.org
- http://www.superreceptionist.in
- http://kwatsi.com
- http://www.smartgoalapp.com
- http://healthifyme.com
- http://www.burufly.com
- http://eatwith.com
- http://en.globalquiz.org
- http://decommentariis.net
- http://www.heapsortjobs.com
- http://demo.organice.io
- https://pizzacharts.com/
- http://www.sendcloud.nl
- http://www.awesound.com

If your site also uses `django-allauth` and you want it to show up in this list
please mail me (raymond.penners@intenct.nl) a link, and I will add it for you.
